responsive_size_extension library

Extensions

ScaleSizeDoubleExtension on double
Get value from int and scale it base on screen size
ScaleSizeExtension on int
Get value from int and scale it base on screen size

Properties

devicePixelRatio double
Get the device pixel
final
physicalHeight double
Get the device screen height
final
physicalWidth double
Get the device screen width
final